<?php
/**
 * Test Generated example demonstrating the Setting.getfields API.
 *
 * Demonstrate return from getfields - see subfolder for variants
 *
 * @return array
 *   API result array
 */
function setting_getfields_example() {
  $params = array();

  try{
    $result = civicrm_api3('Setting', 'getfields', $params);
  }
  catch (CiviCRM_API3_Exception $e) {
    // Handle error here.
    $errorMessage = $e->getMessage();
    $errorCode = $e->getErrorCode();
    $errorData = $e->getExtraParams();
    return array(
      'is_error' => 1,
      'error_message' => $errorMessage,
      'error_code' => $errorCode,
      'error_data' => $errorData,
    );
  }

  return $result;
}

/**
 * Function returns array of result expected from previous function.
 *
 * @return array
 *   API result array
 */
function setting_getfields_expectedresult() {

  $expectedResult = array(
    'is_error' => 0,
    'version' => 3,
    'count' => 151,
    'values' => array(
      'address_standardization_provider' => array(
        'group_name' => 'Address Preferences',
        'group' => 'address',
        'name' => 'address_standardization_provider',
        'type' => 'String',
        'html_type' => 'Select',
        'default' => '',
        'add' => '4.1',
        'title' => 'Address Standardization Provider.',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => 'CiviCRM includes an optional plugin for interfacing with the United States Postal Services (USPS) Address Standardization web service. You must register to use the USPS service at https://www.usps.com/business/web-tools-apis/address-information.htm. If you are approved, they will provide you with a User ID and the URL for the service. Plugins for other address standardization services may be available from 3rd party developers. If installed, they will be included in the drop-down below. ',
      ),
      'address_standardization_userid' => array(
        'group_name' => 'Address Preferences',
        'group' => 'address',
        'name' => 'address_standardization_userid',
        'type' => 'String',
        'html_type' => 'Text',
        'default' => '',
        'add' => '4.1',
        'title' => 'Web service user ID',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'address_standardization_url' => array(
        'group_name' => 'Address Preferences',
        'group' => 'address',
        'name' => 'address_standardization_url',
        'type' => 'Text',
        'html_type' => 'Text',
        'default' => '',
        'add' => '4.1',
        'title' => 'Web Service URL',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => 'Web Service URL',
        'validate_callback' => 'CRM_Utils_Rule::url',
      ),
      'hideCountryMailingLabels' => array(
        'group_name' => 'Address Preferences',
        'group' => 'address',
        'name' => 'hideCountryMailingLabels',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => 0,
        'add' => '4.7',
        'title' => 'Hide Country in Mailing Labels when same as domain country',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Do not display the country field in mailing labels when the country is the same as that of the domain',
        'help_text' => '',
      ),
      'tag_unconfirmed' => array(
        'group_name' => 'Campaign Preferences',
        'group' => 'campaign',
        'name' => 'tag_unconfirmed',
        'type' => 'String',
        'html_type' => 'Text',
        'default' => 'Unconfirmed',
        'add' => '4.1',
        'title' => 'Tag for Unconfirmed Petition Signers',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => 'If set, new contacts that are created when signing a petition are assigned a tag of this name.',
      ),
      'petition_contacts' => array(
        'group_name' => 'Campaign Preferences',
        'group' => 'campaign',
        'name' => 'petition_contacts',
        'type' => 'String',
        'html_type' => 'Text',
        'default' => 'Petition Contacts',
        'add' => '4.1',
        'title' => 'Petition Signers Group',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => 'If set, new contacts that are created when signing a petition are assigned a tag of this name.',
      ),
      'cvv_backoffice_required' => array(
        'group_name' => 'Contribute Preferences',
        'group' => 'contribute',
        'name' => 'cvv_backoffice_required',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => '1',
        'add' => '4.1',
        'title' => 'CVV required for backoffice?',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Is the CVV code required for back office credit card transactions',
        'help_text' => 'If set it back-office credit card transactions will required a cvv code. Leave as required unless you have a very strong reason to change',
      ),
      'contribution_invoice_settings' => array(
        'group_name' => 'Contribute Preferences',
        'group' => 'contribute',
        'name' => 'contribution_invoice_settings',
        'type' => 'Array',
        'default' => array(
          'invoice_prefix' => 'INV_',
          'credit_notes_prefix' => 'CN_',
          'due_date' => '10',
          'due_date_period' => 'days',
          'notes' => '',
          'tax_term' => 'Sales Tax',
          'tax_display_settings' => 'Inclusive',
        ),
        'add' => '4.7',
        'title' => 'Contribution Invoice Settings',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'invoicing' => array(
        'group_name' => 'Contribute Preferences',
        'group' => 'contribute',
        'name' => 'invoicing',
        'type' => 'Integer',
        'html_type' => 'checkbox',
        'quick_form_type' => 'Element',
        'default' => 0,
        'add' => '4.7',
        'title' => 'Enable Tax and Invoicing',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'acl_financial_type' => array(
        'group_name' => 'Contribute Preferences',
        'group' => 'contribute',
        'name' => 'acl_financial_type',
        'type' => 'Integer',
        'html_type' => 'checkbox',
        'quick_form_type' => 'Element',
        'default' => 0,
        'add' => '4.7',
        'title' => 'Enable Access Control by Financial Type',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'deferred_revenue_enabled' => array(
        'group_name' => 'Contribute Preferences',
        'group' => 'contribute',
        'name' => 'deferred_revenue_enabled',
        'type' => 'Integer',
        'html_type' => 'checkbox',
        'quick_form_type' => 'Element',
        'default' => 0,
        'add' => '4.7',
        'title' => 'Enable Deferred Revenue',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'default_invoice_page' => array(
        'group_name' => 'Contribute Preferences',
        'group' => 'contribute',
        'name' => 'default_invoice_page',
        'type' => 'Integer',
        'quick_form_type' => 'Element',
        'default' => '',
        'pseudoconstant' => array(
          'name' => 'contributionPage',
        ),
        'html_type' => 'select',
        'add' => '4.7',
        'title' => 'Default invoice payment page',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'always_post_to_accounts_receivable' => array(
        'group_name' => 'Contribute Preferences',
        'group' => 'contribute',
        'name' => 'always_post_to_accounts_receivable',
        'type' => 'Integer',
        'html_type' => 'checkbox',
        'quick_form_type' => 'Element',
        'default' => 0,
        'add' => '4.7',
        'title' => 'Always post to Accounts Receivable?',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'update_contribution_on_membership_type_change' => array(
        'group_name' => 'Contribute Preferences',
        'group' => 'contribute',
        'name' => 'update_contribution_on_membership_type_change',
        'type' => 'Integer',
        'html_type' => 'checkbox',
        'quick_form_type' => 'Element',
        'default' => 0,
        'add' => '4.7',
        'title' => 'Automatically update related contributions when Membership Type is changed',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Enabling this setting will update related contribution of membership(s) except if the membership is paid for with a recurring contribution.',
        'help_text' => '',
      ),
      'contact_view_options' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'contact_view_options',
        'type' => 'String',
        'html_type' => 'checkboxes',
        'pseudoconstant' => array(
          'optionGroupName' => 'contact_view_options',
        ),
        'default' => '123456789101113',
        'add' => '4.1',
        'title' => 'Viewing Contacts',
        'is_domain' => '1',
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'contact_edit_options' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'contact_edit_options',
        'type' => 'String',
        'html_type' => 'checkboxes',
        'pseudoconstant' => array(
          'optionGroupName' => 'contact_edit_options',
        ),
        'default' => '123456789111214151617',
        'add' => '4.1',
        'title' => 'Editing Contacts',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'advanced_search_options' => array(
        'group_name' => 'CiviCRM Preferences',
        'name' => 'advanced_search_options',
        'type' => 'String',
        'html_type' => 'checkboxes',
        'pseudoconstant' => array(
          'optionGroupName' => 'advanced_search_options',
        ),
        'default' => '123456789101112131516171819',
        'add' => '4.1',
        'title' => 'Contact Search',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'user_dashboard_options' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'user_dashboard_options',
        'type' => 'String',
        'html_type' => 'checkboxes',
        'pseudoconstant' => array(
          'optionGroupName' => 'user_dashboard_options',
        ),
        'default' => '1234578',
        'add' => '4.1',
        'title' => 'Contact Dashboard',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'address_options' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'address_options',
        'type' => 'String',
        'html_type' => 'Text',
        'pseudoconstant' => array(
          'optionGroupName' => 'address_options',
        ),
        'default' => '123456891011',
        'add' => '4.1',
        'title' => 'Addressing Options',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'address_format' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'address_format',
        'type' => 'String',
        'html_type' => 'TextArea',
        'default' => '{contact.address_name}
{contact.street_address}
{contact.supplemental_address_1}
{contact.supplemental_address_2}
{contact.supplemental_address_3}
{contact.city}{, }{contact.state_province}{ }{contact.postal_code}
{contact.country}',
        'add' => '4.1',
        'title' => 'Address Format',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'mailing_format' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'mailing_format',
        'type' => 'String',
        'html_type' => 'Text',
        'default' => '{contact.addressee}
{contact.street_address}
{contact.supplemental_address_1}
{contact.supplemental_address_2}
{contact.supplemental_address_3}
{contact.city}{, }{contact.state_province}{ }{contact.postal_code}
{contact.country}',
        'add' => '4.1',
        'title' => 'Mailing Format',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'display_name_format' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'display_name_format',
        'type' => 'String',
        'html_type' => 'Text',
        'default' => '{contact.individual_prefix}{ }{contact.first_name}{ }{contact.last_name}{ }{contact.individual_suffix}',
        'add' => '4.1',
        'title' => 'Display Name Format',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'sort_name_format' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'sort_name_format',
        'type' => 'String',
        'html_type' => 'Text',
        'default' => '{contact.last_name}{, }{contact.first_name}',
        'add' => '4.1',
        'title' => 'Sort Name Format',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'remote_profile_submissions' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'remote_profile_submissions',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => '',
        'html_type' => 'radio',
        'add' => '4.7',
        'title' => 'Accept profile submissions from external sites',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'If enabled, CiviCRM will permit submissions from external sites to profiles. This is disabled by default to limit abuse.',
        'help_text' => '',
      ),
      'editor_id' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'editor_id',
        'type' => 'String',
        'html_type' => 'Select',
        'default' => 'CKEditor',
        'add' => '4.1',
        'title' => 'Wysiwig Editor',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'contact_ajax_check_similar' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'contact_ajax_check_similar',
        'type' => 'String',
        'html_type' => 'Text',
        'default' => '1',
        'add' => '4.1',
        'title' => 'Ajax Check Similar',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'ajaxPopupsEnabled' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'ajaxPopupsEnabled',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => 1,
        'add' => '4.5',
        'title' => 'Ajax Popups Enabled',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'activity_assignee_notification' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'activity_assignee_notification',
        'type' => 'String',
        'html_type' => 'Text',
        'default' => '1',
        'add' => '4.1',
        'title' => 'Notify Activity Assignees',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'activity_assignee_notification_ics' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'activity_assignee_notification_ics',
        'type' => 'String',
        'html_type' => 'Text',
        'default' => 0,
        'add' => '4.3',
        'title' => 'Include ICal Invite to Activity Assignees',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'contact_autocomplete_options' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'contact_autocomplete_options',
        'type' => 'String',
        'quick_form_type' => 'CheckBox',
        'pseudoconstant' => array(
          'callback' => 'CRM_Admin_Form_Setting_Search::getContactAutocompleteOptions',
        ),
        'default' => '12',
        'add' => '4.1',
        'title' => 'Autocomplete Contact Search',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Selected fields will be displayed in back-office autocomplete dropdown search results (Quick Search, etc.). Contact Name is always included.',
        'help_text' => '',
      ),
      'contact_reference_options' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'contact_reference_options',
        'type' => 'String',
        'quick_form_type' => 'CheckBox',
        'pseudoconstant' => array(
          'callback' => 'CRM_Admin_Form_Setting_Search::getContactReferenceOptions',
        ),
        'default' => '12',
        'add' => '4.1',
        'title' => 'Contact Reference Options',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Selected fields will be displayed in autocomplete dropdown search results for \'Contact Reference\' custom fields. Contact Name is always included. NOTE: You must assign \'access contact reference fields\' permission to the anonymous role if you want to use custom contact reference fields in profiles on public pages. For most situations, you should use the \'Limit List to Group\' setting when configuring a contact reference field which will be used in public forms to prevent exposing your entire contact list.',
        'help_text' => '',
      ),
      'contact_smart_group_display' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'contact_smart_group_display',
        'type' => 'String',
        'html_type' => 'radio',
        'default' => '1',
        'add' => '4.7',
        'title' => 'Viewing Smart Groups',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'smart_group_cache_refresh_mode' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'smart_group_cache_refresh_mode',
        'type' => 'String',
        'html_type' => 'radio',
        'default' => 'opportunistic',
        'add' => '4.7',
        'title' => 'Smart Group Refresh Mode',
        'is_domain' => 1,
        'is_contact' => 0,
        'pseudoconstant' => array(
          'callback' => 'CRM_Contact_BAO_GroupContactCache::getModes',
        ),
        'description' => 'Should the smart groups be by cron jobs or user actions',
        'help_text' => 'In \"Opportunistic Flush\" mode, caches are flushed in response to user actions; this mode is broadly compatible but may add latency during form-submissions. In \"Cron Flush\" mode, you should schedule a cron job to flush caches; this can improve latency on form-submissions but requires more setup.',
      ),
      'installed' => array(
        'bootstrap_comment' => 'This is a boot setting which may be loaded during bootstrap. Defaults are loaded via SettingsBag::getSystemDefaults().',
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'installed',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => '',
        'add' => '4.7',
        'title' => 'System Installed',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'A flag indicating whether this system has run a post-installation routine',
        'help_text' => '',
      ),
      'max_attachments' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'max_attachments',
        'legacy_key' => 'maxAttachments',
        'type' => 'Integer',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'html_attributes' => array(
          'size' => 2,
          'maxlength' => 8,
        ),
        'default' => 3,
        'add' => '4.3',
        'title' => 'Maximum Attachments',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Maximum number of files (documents, images, etc.) which can attached to emails or activities.',
        'help_text' => '',
      ),
      'maxFileSize' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'maxFileSize',
        'type' => 'Integer',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'html_attributes' => array(
          'size' => 2,
          'maxlength' => 8,
        ),
        'default' => 3,
        'add' => '4.3',
        'title' => 'Maximum File Size (in MB)',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Maximum Size of file (documents, images, etc.) which can attached to emails or activities.<br />Note: php.ini should support this file size.',
        'help_text' => '',
      ),
      'contact_undelete' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'contact_undelete',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => 1,
        'add' => '4.3',
        'title' => 'Contact Trash and Undelete',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'If enabled, deleted contacts will be moved to trash (instead of being destroyed). Users with the proper permission are able to search for the deleted contacts and restore them (or delete permanently).',
        'help_text' => '',
      ),
      'allowPermDeleteFinancial' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'allowPermDeleteFinancial',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => '',
        'add' => '4.3',
        'title' => 'Contact Permanent Delete',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Allow Permanent Delete for contacts who are linked to live financial transactions',
        'help_text' => '',
      ),
      'securityAlert' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'securityAlert',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => 1,
        'add' => '4.4',
        'title' => 'Status Alerts',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'If enabled, CiviCRM will display pop-up notifications (no more than once per day) for security and misconfiguration issues identified in the system check.',
        'help_text' => '',
      ),
      'doNotAttachPDFReceipt' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'doNotAttachPDFReceipt',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => 0,
        'add' => '4.3',
        'title' => 'Attach PDF copy to receipts',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'If enabled, CiviCRM sends PDF receipt as an attachment during event signup or online contribution.',
        'help_text' => '',
      ),
      'wkhtmltopdfPath' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'wkhtmltopdfPath',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_attributes' => array(
          'size' => 64,
          'maxlength' => 256,
        ),
        'html_type' => 'Text',
        'default' => '',
        'add' => '4.3',
        'title' => 'Path to wkhtmltopdf executable',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'recaptchaOptions' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'recaptchaOptions',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_attributes' => array(
          'size' => 64,
          'maxlength' => 64,
        ),
        'html_type' => 'Text',
        'default' => '',
        'add' => '4.3',
        'title' => 'Recaptcha Options',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'You can specify the reCAPTCHA theme options as comma separated data.(eg: theme:\'blackglass\', lang : \'fr\' ). Check the available options at <a href=\"https://developers.google.com/recaptcha/docs/display#config\">Customizing the Look and Feel of reCAPTCHA</a>.',
        'help_text' => '',
      ),
      'recaptchaPublicKey' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'recaptchaPublicKey',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_attributes' => array(
          'size' => 64,
          'maxlength' => 64,
        ),
        'html_type' => 'Text',
        'default' => '',
        'add' => '4.3',
        'title' => 'Recaptcha Site Key',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'recaptchaPrivateKey' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'recaptchaPrivateKey',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_attributes' => array(
          'size' => 64,
          'maxlength' => 64,
        ),
        'html_type' => 'Text',
        'default' => '',
        'add' => '4.3',
        'title' => 'Recaptcha Secret Key',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'checksum_timeout' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'checksum_timeout',
        'type' => 'Integer',
        'quick_form_type' => 'Element',
        'html_attributes' => array(
          'size' => 2,
          'maxlength' => 8,
        ),
        'html_type' => 'Text',
        'default' => 7,
        'add' => '4.3',
        'title' => 'Checksum Lifespan',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'blogUrl' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'blogUrl',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_attributes' => array(
          'size' => 64,
          'maxlength' => 128,
        ),
        'html_type' => 'Text',
        'default' => '*default*',
        'add' => '4.3',
        'title' => 'Blog Feed URL',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Blog feed URL used by the blog dashlet',
        'help_text' => 'Use \"*default*\" for the system default or override with a custom URL',
      ),
      'communityMessagesUrl' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'communityMessagesUrl',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_attributes' => array(
          'size' => 64,
          'maxlength' => 128,
        ),
        'html_type' => 'Text',
        'default' => '*default*',
        'add' => '4.3',
        'title' => 'Community Messages URL',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Service providing CiviCRM community messages',
        'help_text' => 'Use \"*default*\" for the system default or override with a custom URL',
      ),
      'gettingStartedUrl' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'gettingStartedUrl',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_attributes' => array(
          'size' => 64,
          'maxlength' => 128,
        ),
        'html_type' => 'Text',
        'default' => '*default*',
        'add' => '4.3',
        'title' => 'Getting Started URL',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Service providing the Getting Started data',
        'help_text' => 'Use \"*default*\" for the system default or override with a custom URL',
      ),
      'resCacheCode' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'resCacheCode',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'default' => '',
        'add' => '4.3',
        'title' => 'resCacheCode',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Code appended to resource URLs (JS/CSS) to coerce HTTP caching',
        'help_text' => '',
      ),
      'verifySSL' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'verifySSL',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => 1,
        'add' => '4.3',
        'title' => 'Verify SSL?',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'If disabled, outbound web-service requests will allow unverified, insecure HTTPS connections',
        'help_text' => 'Unless you are absolutely unable to configure your server to check the SSL certificate of the remote server you should leave this set to Yes',
      ),
      'enableSSL' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'enableSSL',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => 0,
        'add' => '4.5',
        'title' => 'Force SSL?',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'If enabled, inbound HTTP requests for sensitive pages will be redirected to HTTPS.',
        'help_text' => 'If enabled, inbound HTTP requests for sensitive pages will be redirected to HTTPS.',
      ),
      'wpBasePage' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'wpBasePage',
        'type' => 'String',
        'html_type' => 'text',
        'quick_form_type' => 'Element',
        'default' => '',
        'add' => '4.3',
        'title' => 'WordPress Base Page',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'If set, CiviCRM will use this setting as the base url.',
        'help_text' => 'By default, CiviCRM will generate front-facing pages using the home page at http://wp/ as its base. If you want to use a different template for CiviCRM pages, set the path here.',
      ),
      'secondDegRelPermissions' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'secondDegRelPermissions',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => 0,
        'add' => '4.3',
        'title' => 'Allow second-degree relationship permissions',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'If enabled, contacts with the permission to edit a related contact will inherit that contact\'s permission to edit other related contacts',
        'help_text' => '',
      ),
      'enable_components' => array(
        'bootstrap_comment' => 'This is a boot setting which may be loaded during bootstrap. Defaults are loaded via SettingsBag::getSystemDefaults().',
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'enable_components',
        'type' => 'Array',
        'quick_form_type' => 'Element',
        'html_type' => 'advmultiselect',
        'html_attributes' => array(
          'size' => 5,
          'style' => 'width:150px',
          'class' => 'advmultiselect',
        ),
        'default' => '',
        'add' => '4.4',
        'title' => 'Enable Components',
        'is_domain' => '1',
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
        'on_change' => array(
          '0' => 'CRM_Case_Info::onToggleComponents',
          '1' => 'CRM_Core_Component::flushEnabledComponents',
          '2' => 'call://resources/resetCacheCode',
        ),
      ),
      'disable_core_css' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'disable_core_css',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => 0,
        'add' => '4.4',
        'title' => 'Disable CiviCRM css',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Prevent the stylesheet \"civicrm.css\" from being loaded.',
        'help_text' => '',
      ),
      'empoweredBy' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'empoweredBy',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => 1,
        'add' => '4.5',
        'title' => 'Display \"empowered by CiviCRM\"',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'When enabled, \"empowered by CiviCRM\" is displayed at the bottom of public forms.',
        'help_text' => '',
      ),
      'logging_no_trigger_permission' => array(
        'add' => '4.7',
        'is_domain' => 1,
        'is_contact' => 0,
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'help_text' => '(EXPERIMENTAL) If the MySQL user does not have permission to administer triggers, then you must create the triggers outside CiviCRM. No support is provided for this configuration.',
        'name' => 'logging_no_trigger_permission',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'html_type' => '',
        'default' => 0,
        'title' => '(EXPERIMENTAL) MySQL user does not have trigger permissions',
        'description' => 'Set this when you intend to manage trigger creation outside of CiviCRM',
      ),
      'logging' => array(
        'add' => '4.7',
        'help_text' => '',
        'is_domain' => 1,
        'is_contact' => 0,
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'logging',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'html_type' => '',
        'default' => 0,
        'title' => 'Logging',
        'description' => 'If enabled, all actions will be logged with a complete record of changes.',
        'validate_callback' => 'CRM_Logging_Schema::checkLoggingSupport',
        'on_change' => array(
          '0' => 'CRM_Logging_Schema::onToggle',
        ),
      ),
      'logging_uniqueid_date' => array(
        'add' => '4.7',
        'help_text' => 'This is the date when CRM-18193 was implemented',
        'is_domain' => 1,
        'is_contact' => 0,
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'logging_uniqueid_date',
        'type' => 'Date',
        'quick_form_type' => 'DateTime',
        'html_type' => '',
        'default' => '',
        'title' => 'Logging Unique ID not recorded before',
        'description' => 'This is the date when CRM-18193 was implemented',
      ),
      'logging_all_tables_uniquid' => array(
        'add' => '4.7',
        'help_text' => 'This indicates there are no tables holdng pre-uniqid log_conn_id values (CRM-18193)',
        'is_domain' => 1,
        'is_contact' => 0,
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'logging_all_tables_uniquid',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'html_type' => '',
        'default' => 0,
        'title' => 'All tables use Unique Connection ID',
        'description' => 'Do some tables pre-date CRM-18193?',
      ),
      'userFrameworkUsersTableName' => array(
        'add' => '4.7',
        'help_text' => '',
        'is_domain' => 1,
        'is_contact' => 0,
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'userFrameworkUsersTableName',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'html_attributes' => array(
          'size' => '32',
          'maxlength' => '64',
        ),
        'default' => '',
        'title' => 'Drupal Users Table Name',
        'description' => '',
      ),
      'wpLoadPhp' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'wpLoadPhp',
        'type' => 'String',
        'html_type' => 'text',
        'quick_form_type' => 'Element',
        'default' => '',
        'add' => '4.6',
        'title' => 'WordPress Path to wp-load.php',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'CiviCRM will use this setting as path to bootstrap WP.',
        'help_text' => '',
      ),
      'secure_cache_timeout_minutes' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'secure_cache_timeout_minutes',
        'type' => 'Integer',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'html_attributes' => array(
          'size' => 2,
          'maxlength' => 8,
        ),
        'default' => 20,
        'add' => '4.7',
        'title' => 'Secure Cache Timeout',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Maximum number of minutes that secure form data should linger',
        'help_text' => '',
      ),
      'site_id' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'site_id',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'default' => '',
        'add' => '4.6',
        'title' => 'Unique Site ID',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'systemStatusCheckResult' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'systemStatusCheckResult',
        'type' => 'Integer',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'default' => 0,
        'add' => '4.7',
        'title' => 'systemStatusCheckResult',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'recentItemsMaxCount' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'recentItemsMaxCount',
        'type' => 'Integer',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'html_attributes' => array(
          'size' => 2,
          'maxlength' => 3,
        ),
        'default' => 20,
        'add' => '4.7',
        'title' => 'Size of \"Recent Items\" stack',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'How many items should CiviCRM store in it\'s \"Recently viewed\" list.',
        'help_text' => '',
      ),
      'recentItemsProviders' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'recentItemsProviders',
        'type' => 'Array',
        'html_type' => 'Select',
        'quick_form_type' => 'Select',
        'html_attributes' => array(
          'multiple' => 1,
          'class' => 'crm-select2',
        ),
        'default' => '',
        'add' => '4.7',
        'title' => 'Recent Items Providers',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'What providers may save views in CiviCRM\'s \"Recently viewed\" list. If empty, all are in.',
        'help_text' => '',
        'pseudoconstant' => array(
          'callback' => 'CRM_Utils_Recent::getProviders',
        ),
      ),
      'dedupe_default_limit' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'dedupe_default_limit',
        'type' => 'Integer',
        'default' => 0,
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'add' => '4.7',
        'title' => 'Default limit for dedupe screen',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Default to only loading matches against this number of contacts',
        'help_text' => 'Deduping larger databases can crash the server. By configuring a limit other than 0 here the dedupe query will only search for matches against a limited number of contacts.',
      ),
      'syncCMSEmail' => array(
        'group_name' => 'CiviCRM Preferences',
        'group' => 'core',
        'name' => 'syncCMSEmail',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => 1,
        'add' => '4.7',
        'title' => 'Sync CMS Email',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'If enabled, then CMS email id will be syncronised with CiviCRM contacts\'s primary email.',
        'help_text' => '',
      ),
      'userFrameworkLogging' => array(
        'group_name' => 'Developer Preferences',
        'group' => 'developer',
        'name' => 'userFrameworkLogging',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => 0,
        'add' => '4.3',
        'title' => 'Enable Drupal Watchdog Logging',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Set this value to Yes if you want CiviCRM error/debugging messages to appear in the Drupal error logs',
        'help_text' => 'Set this value to Yes if you want CiviCRM error/debugging messages the appear in your CMS\' error log. In the case of Drupal, this will cause all CiviCRM error messages to appear in the watchdog (assuming you have Drupal\'s watchdog enabled)',
      ),
      'debug_enabled' => array(
        'group_name' => 'Developer Preferences',
        'group' => 'developer',
        'name' => 'debug_enabled',
        'config_key' => 'debug',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => 0,
        'add' => '4.3',
        'title' => 'Enable Debugging',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Set this value to Yes if you want to use one of CiviCRM\'s debugging tools. This feature should NOT be enabled for production sites',
        'help_text' => 'Do not turn this on on production sites',
      ),
      'backtrace' => array(
        'group_name' => 'Developer Preferences',
        'group' => 'developer',
        'name' => 'backtrace',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => 0,
        'add' => '4.3',
        'title' => 'Display Backtrace',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Set this value to Yes if you want to display a backtrace listing when a fatal error is encountered. This feature should NOT be enabled for production sites',
      ),
      'fatalErrorHandler' => array(
        'group_name' => 'Developer Preferences',
        'group' => 'developer',
        'name' => 'fatalErrorHandler',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'default' => '',
        'add' => '4.3',
        'title' => 'Fatal Error Handler',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Enter the path and class for a custom PHP error-handling function if you want to override built-in CiviCRM error handling for your site.',
      ),
      'uploadDir' => array(
        'bootstrap_comment' => 'This is a boot setting which may be loaded during bootstrap. Defaults are loaded via SettingsBag::getSystemDefaults().',
        'group_name' => 'Directory Preferences',
        'group' => 'directory',
        'name' => 'uploadDir',
        'type' => 'String',
        'html_type' => 'Text',
        'quick_form_type' => 'Element',
        'default' => '',
        'add' => '4.1',
        'title' => 'Temporary Files Directory',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => 'File system path where temporary CiviCRM files - such as import data files - are uploaded.',
      ),
      'imageUploadDir' => array(
        'bootstrap_comment' => 'This is a boot setting which may be loaded during bootstrap. Defaults are loaded via SettingsBag::getSystemDefaults().',
        'group_name' => 'Directory Preferences',
        'group' => 'directory',
        'name' => 'imageUploadDir',
        'type' => 'String',
        'html_type' => 'Text',
        'quick_form_type' => 'Element',
        'default' => '',
        'add' => '4.1',
        'title' => 'Image Directory',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'File system path where image files are uploaded. Currently, this path is used for images associated with premiums (CiviContribute thank-you gifts).',
        'help_text' => '',
      ),
      'customFileUploadDir' => array(
        'bootstrap_comment' => 'This is a boot setting which may be loaded during bootstrap. Defaults are loaded via SettingsBag::getSystemDefaults().',
        'group_name' => 'Directory Preferences',
        'group' => 'directory',
        'name' => 'customFileUploadDir',
        'type' => 'String',
        'html_type' => 'Text',
        'quick_form_type' => 'Element',
        'default' => '',
        'add' => '4.1',
        'title' => 'Custom Files Directory',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Path where documents and images which are attachments to contact records are stored (e.g. contact photos, resumes, contracts, etc.). These attachments are defined using \'file\' type custom fields.',
        'help_text' => '',
      ),
      'customTemplateDir' => array(
        'bootstrap_comment' => 'This is a boot setting which may be loaded during bootstrap. Defaults are loaded via SettingsBag::getSystemDefaults().',
        'group_name' => 'Directory Preferences',
        'group' => 'directory',
        'name' => 'customTemplateDir',
        'type' => 'String',
        'html_type' => 'Text',
        'quick_form_type' => 'Element',
        'default' => '',
        'add' => '4.1',
        'title' => 'Custom Template Directory',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Path where site specific templates are stored if any. This directory is searched first if set. Custom JavaScript code can be added to templates by creating files named templateFile.extra.tpl. (learn more...)',
        'help_text' => '',
      ),
      'customPHPPathDir' => array(
        'bootstrap_comment' => 'This is a boot setting which may be loaded during bootstrap. Defaults are loaded via SettingsBag::getSystemDefaults().',
        'group_name' => 'Directory Preferences',
        'group' => 'directory',
        'name' => 'customPHPPathDir',
        'type' => 'String',
        'html_type' => 'Text',
        'quick_form_type' => 'Element',
        'default' => '',
        'add' => '4.1',
        'title' => 'Custom PHP Directory',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Path where site specific PHP code files are stored if any. This directory is searched first if set.',
        'help_text' => '',
      ),
      'extensionsDir' => array(
        'bootstrap_comment' => 'This is a boot setting which may be loaded during bootstrap. Defaults are loaded via SettingsBag::getSystemDefaults().',
        'group_name' => 'Directory Preferences',
        'group' => 'directory',
        'name' => 'extensionsDir',
        'type' => 'String',
        'html_type' => 'Text',
        'quick_form_type' => 'Element',
        'default' => '',
        'add' => '4.1',
        'title' => 'Extensions Directory',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Path where CiviCRM extensions are stored.',
        'help_text' => '',
      ),
      'enable_cart' => array(
        'name' => 'enable_cart',
        'group_name' => 'Event Preferences',
        'group' => 'event',
        'type' => 'Boolean',
        'quick_form_type' => 'Element',
        'default' => 0,
        'add' => '4.1',
        'title' => 'Enable Event Cart',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'WRITE ME',
        'help_text' => 'WRITE ME',
      ),
      'show_events' => array(
        'name' => 'show_events',
        'group_name' => 'Event Preferences',
        'group' => 'event',
        'type' => 'Integer',
        'quick_form_type' => 'Element',
        'default' => 10,
        'add' => '4.5',
        'title' => 'Dashboard entries',
        'html_type' => 'select',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Configure how many events should be shown on the dashboard. This overrides the default value of 10 entries.',
        'help_text' => '',
      ),
      'ext_repo_url' => array(
        'group_name' => 'Extension Preferences',
        'group' => 'ext',
        'name' => 'ext_repo_url',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_attributes' => array(
          'size' => 64,
          'maxlength' => 128,
        ),
        'html_type' => 'Text',
        'default' => 'https://civicrm.org/extdir/ver={ver}|cms={uf}',
        'add' => '4.3',
        'title' => 'Extension Repo URL',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'customTranslateFunction' => array(
        'add' => '4.7',
        'help_text' => '',
        'is_domain' => 1,
        'is_contact' => 0,
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'customTranslateFunction',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'html_attributes' => array(
          'size' => '30',
          'maxlength' => '100',
        ),
        'default' => '',
        'title' => 'Custom Translate Function',
        'description' => '',
      ),
      'monetaryThousandSeparator' => array(
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'monetaryThousandSeparator',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'html_attributes' => array(
          'size' => 2,
        ),
        'default' => ',',
        'add' => '4.3',
        'title' => 'Thousands Separator',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'monetaryDecimalPoint' => array(
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'monetaryDecimalPoint',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'html_attributes' => array(
          'size' => 2,
        ),
        'default' => '.',
        'add' => '4.3',
        'title' => 'Decimal Delimiter',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'moneyformat' => array(
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'moneyformat',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'default' => '%c %a',
        'add' => '4.3',
        'title' => 'Monetary Amount Display',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'moneyvalueformat' => array(
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'moneyvalueformat',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'default' => '%!i',
        'add' => '4.3',
        'title' => 'Monetary Value Display',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'defaultCurrency' => array(
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'defaultCurrency',
        'type' => 'String',
        'quick_form_type' => 'Select',
        'html_type' => 'Select',
        'html_attributes' => array(
          'class' => 'crm-select2',
        ),
        'default' => 'USD',
        'add' => '4.3',
        'title' => 'Default Currency',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Default currency assigned to contributions and other monetary transactions.',
        'help_text' => '',
        'pseudoconstant' => array(
          'callback' => 'CRM_Admin_Form_Setting_Localization::getCurrencySymbols',
        ),
      ),
      'defaultContactCountry' => array(
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'defaultContactCountry',
        'type' => 'String',
        'quick_form_type' => 'Select',
        'html_type' => 'Select',
        'html_attributes' => array(),
        'default' => '1228',
        'add' => '4.4',
        'title' => 'Default Country',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'This value is selected by default when adding a new contact address.',
        'help_text' => '',
        'pseudoconstant' => array(
          'callback' => 'CRM_Admin_Form_Setting_Localization::getAvailableCountries',
        ),
      ),
      'defaultContactStateProvince' => array(
        'add' => '4.7',
        'help_text' => '',
        'is_domain' => 1,
        'is_contact' => 0,
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'defaultContactStateProvince',
        'type' => 'Integer',
        'quick_form_type' => 'ChainSelect',
        'html_type' => 'ChainSelect',
        'default' => '',
        'title' => 'Default State/Province',
        'description' => 'This value is selected by default when adding a new contact address.',
      ),
      'countryLimit' => array(
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'countryLimit',
        'type' => 'Array',
        'quick_form_type' => 'Element',
        'html_type' => 'advmultiselect',
        'html_attributes' => array(
          'size' => 5,
          'style' => 'width:150px',
          'class' => 'advmultiselect',
        ),
        'default' => array(),
        'add' => '4.3',
        'title' => 'Available Countries',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
        'pseudoconstant' => array(
          'callback' => 'CRM_Admin_Form_Setting_Localization::getAvailableCountries',
        ),
      ),
      'provinceLimit' => array(
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'provinceLimit',
        'type' => 'Array',
        'quick_form_type' => 'Element',
        'html_type' => 'advmultiselect',
        'html_attributes' => array(
          'size' => 5,
          'style' => 'width:150px',
          'class' => 'advmultiselect',
        ),
        'default' => array(),
        'add' => '4.3',
        'title' => 'Available States and Provinces (by Country)',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
        'pseudoconstant' => array(
          'callback' => 'CRM_Admin_Form_Setting_Localization::getAvailableCountries',
        ),
      ),
      'inheritLocale' => array(
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'inheritLocale',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => 0,
        'add' => '4.3',
        'title' => 'Inherit CMS Language',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'dateformatDatetime' => array(
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'dateformatDatetime',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'default' => '%B %E%f, %Y %l:%M %P',
        'add' => '4.3',
        'title' => 'Date Format: Complete Date and Time',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'dateformatFull' => array(
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'dateformatFull',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'default' => '%B %E%f, %Y',
        'add' => '4.3',
        'title' => 'Date Format: Complete Date',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'dateformatPartial' => array(
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'dateformatPartial',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'default' => '%B %Y',
        'add' => '4.3',
        'title' => 'Date Format: Month and Year',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'dateformatTime' => array(
        'add' => '4.7',
        'help_text' => '',
        'is_domain' => 1,
        'is_contact' => 0,
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'dateformatTime',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'html_attributes' => array(
          'size' => '12',
          'maxlength' => '60',
        ),
        'default' => '%l:%M %P',
        'title' => 'Date Format: Time Only',
        'description' => '',
      ),
      'dateformatYear' => array(
        'add' => '4.7',
        'help_text' => '',
        'is_domain' => 1,
        'is_contact' => 0,
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'dateformatYear',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'html_attributes' => array(
          'size' => '12',
          'maxlength' => '60',
        ),
        'default' => '%Y',
        'title' => 'Date Format: Year Only',
        'description' => '',
      ),
      'dateformatFinancialBatch' => array(
        'add' => '4.7',
        'help_text' => '',
        'is_domain' => 1,
        'is_contact' => 0,
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'dateformatFinancialBatch',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'html_attributes' => array(
          'size' => '12',
          'maxlength' => '60',
        ),
        'default' => '%m/%d/%Y',
        'title' => 'Date Format: Financial Batch',
        'description' => '',
      ),
      'dateformatshortdate' => array(
        'add' => '4.7',
        'help_text' => '',
        'is_domain' => 1,
        'is_contact' => 0,
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'dateformatshortdate',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'html_attributes' => array(
          'size' => '12',
          'maxlength' => '60',
        ),
        'default' => '%m/%d/%Y',
        'title' => 'Date Format: Short date Month Day Year',
        'description' => '',
      ),
      'dateInputFormat' => array(
        'add' => '4.7',
        'help_text' => '',
        'is_domain' => 1,
        'is_contact' => 0,
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'dateInputFormat',
        'type' => 'String',
        'quick_form_type' => 'Select',
        'html_type' => 'Select',
        'pseudoconstant' => array(
          'callback' => 'CRM_Core_SelectValues::getDatePluginInputFormats',
        ),
        'default' => 'mm/dd/yy',
        'title' => 'Date Input Format',
        'description' => '',
      ),
      'fieldSeparator' => array(
        'add' => '4.7',
        'help_text' => '',
        'is_domain' => 1,
        'is_contact' => 0,
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'fieldSeparator',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'html_attributes' => array(
          'size' => '2',
          'maxlength' => '8',
        ),
        'default' => ',',
        'title' => 'Import / Export Field Separator',
        'description' => 'Global CSV separator character. Modify this setting to enable import and export of different kinds of CSV files (for example: \',\' \';\' \':\' \'|\' ).',
      ),
      'fiscalYearStart' => array(
        'add' => '4.7',
        'help_text' => '',
        'is_domain' => 1,
        'is_contact' => 0,
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'fiscalYearStart',
        'type' => 'Array',
        'quick_form_type' => 'MonthDay',
        'html_type' => 'MonthDay',
        'default' => array(
          'M' => 1,
          'd' => 1,
        ),
        'title' => 'Fiscal Year Start',
        'description' => '',
      ),
      'languageLimit' => array(
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'languageLimit',
        'type' => 'Array',
        'quick_form_type' => 'Select',
        'html_type' => 'Select',
        'html_attributes' => array(
          'multiple' => 1,
          'class' => 'crm-select2',
        ),
        'default' => '',
        'add' => '4.3',
        'title' => 'Available Languages (Multi-lingual)',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
        'pseudoconstant' => array(
          'callback' => 'CRM_Core_I18n::languages',
        ),
      ),
      'lcMessages' => array(
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'lcMessages',
        'type' => 'String',
        'quick_form_type' => 'Select',
        'html_type' => 'Select',
        'html_attributes' => array(
          'class' => 'crm-select2',
        ),
        'default' => 'en_US',
        'add' => '4.3',
        'title' => 'Default Language',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
        'pseudoconstant' => array(
          'callback' => 'CRM_Admin_Form_Setting_Localization::getDefaultLocaleOptions',
        ),
        'on_change' => array(
          '0' => 'CRM_Admin_Form_Setting_Localization::onChangeLcMessages',
        ),
      ),
      'legacyEncoding' => array(
        'add' => '4.7',
        'help_text' => '',
        'is_domain' => 1,
        'is_contact' => 0,
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'legacyEncoding',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'html_attributes' => array(
          'size' => '12',
          'maxlength' => '30',
        ),
        'default' => 'Windows-1252',
        'title' => 'Legacy Encoding',
        'description' => 'If import files are NOT encoded as UTF-8, specify an alternate character encoding for these files. The default of Windows-1252 will work for Excel-created .CSV files on many computers.',
      ),
      'timeInputFormat' => array(
        'add' => '4.7',
        'help_text' => '',
        'is_domain' => 1,
        'is_contact' => 0,
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'timeInputFormat',
        'type' => 'String',
        'quick_form_type' => 'Select',
        'html_type' => 'Select',
        'pseudoconstant' => array(
          'callback' => 'CRM_Core_SelectValues::getTimeFormats',
        ),
        'default' => '1',
        'title' => 'Time Input Format',
        'description' => '',
        'on_change' => array(
          '0' => 'CRM_Core_BAO_PreferencesDate::onChangeSetting',
        ),
      ),
      'weekBegins' => array(
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'weekBegins',
        'type' => 'String',
        'quick_form_type' => 'Select',
        'html_type' => 'Select',
        'pseudoconstant' => array(
          'callback' => 'CRM_Utils_Date::getFullWeekdayNames',
        ),
        'default' => 0,
        'add' => '4.7',
        'title' => 'Week begins on',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'contact_default_language' => array(
        'group_name' => 'Localization Preferences',
        'group' => 'localization',
        'name' => 'contact_default_language',
        'type' => 'String',
        'quick_form_type' => 'Select',
        'html_type' => 'Select',
        'html_attributes' => array(
          'class' => 'crm-select2',
        ),
        'pseudoconstant' => array(
          'callback' => 'CRM_Admin_Form_Setting_Localization::getDefaultLanguageOptions',
        ),
        'default' => '*default*',
        'add' => '4.7',
        'title' => 'Default Language for contacts',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Default language (if any) for contact records',
        'help_text' => 'If a contact is created with no language this setting will determine the language data (if any) to save.You may or may not wish to make an assumption here about whether it matches the site language',
      ),
      'profile_double_optin' => array(
        'group_name' => 'Mailing Preferences',
        'group' => 'mailing',
        'name' => 'profile_double_optin',
        'type' => 'Integer',
        'html_type' => 'checkbox',
        'default' => '1',
        'add' => '4.1',
        'title' => 'Enable Double Opt-in for Profile Group(s) field',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'When CiviMail is enabled, users who \"subscribe\" to a group from a profile Group(s) checkbox will receive a confirmation email. They must respond (opt-in) before they are added to the group.',
        'help_text' => '',
      ),
      'track_civimail_replies' => array(
        'group_name' => 'Mailing Preferences',
        'group' => 'mailing',
        'name' => 'track_civimail_replies',
        'type' => 'Integer',
        'html_type' => 'checkbox',
        'default' => 0,
        'add' => '4.1',
        'title' => 'Track replies using VERP in Reply-To header',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'If checked, mailings will default to tracking replies using VERP-ed Reply-To. ',
        'help_text' => '',
        'validate_callback' => 'CRM_Core_BAO_Setting::validateBoolSetting',
      ),
      'civimail_workflow' => array(
        'group_name' => 'Mailing Preferences',
        'group' => 'mailing',
        'name' => 'civimail_workflow',
        'type' => 'Integer',
        'html_type' => 'checkbox',
        'default' => 0,
        'add' => '4.1',
        'title' => 'Use CiviMail Workflow',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'When CiviMail is enabled, users who \"subscribe\" to a group from a profile Group(s) checkbox will receive a confirmation email. They must respond (opt-in) before they are added to the group.',
        'help_text' => '',
      ),
      'civimail_server_wide_lock' => array(
        'group_name' => 'Mailing Preferences',
        'group' => 'mailing',
        'name' => 'civimail_server_wide_lock',
        'type' => 'Integer',
        'html_type' => 'checkbox',
        'default' => 0,
        'add' => '4.1',
        'title' => 'Lock Mails Server-Wide for Mail Sending',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'replyTo' => array(
        'group_name' => 'Mailing Preferences',
        'group' => 'mailing',
        'name' => 'replyTo',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => 0,
        'add' => '4.6',
        'title' => 'Enable Custom Reply-To',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Allow CiviMail users to send mailings with a custom Reply-To header',
        'help_text' => '',
      ),
      'mailing_backend' => array(
        'group_name' => 'Mailing Preferences',
        'group' => 'mailing',
        'name' => 'mailing_backend',
        'type' => 'Array',
        'html_type' => 'checkbox',
        'default' => array(
          'outBound_option' => '3',
        ),
        'add' => '4.1',
        'title' => 'Mailing Backend',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'profile_add_to_group_double_optin' => array(
        'group_name' => 'Mailing Preferences',
        'group' => 'mailing',
        'name' => 'profile_add_to_group_double_optin',
        'type' => 'Integer',
        'html_type' => 'checkbox',
        'default' => 0,
        'add' => '4.1',
        'title' => 'Enable Double Opt-in for Profile Group(s) field',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'When CiviMail is enabled, users who \"subscribe\" to a group from a profile Group(s) checkbox will receive a confirmation email. They must respond (opt-in) before they are added to the group.',
        'help_text' => '',
      ),
      'disable_mandatory_tokens_check' => array(
        'group_name' => 'Mailing Preferences',
        'group' => 'mailing',
        'name' => 'disable_mandatory_tokens_check',
        'type' => 'Integer',
        'html_type' => 'checkbox',
        'default' => 0,
        'add' => '4.4',
        'title' => 'Disable check for mandatory tokens',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Don\'t check for presence of mandatory tokens (domain address; unsubscribe/opt-out) before sending mailings. WARNING: Mandatory tokens are a safe-guard which facilitate compliance with the US CAN-SPAM Act. They should only be disabled if your organization adopts other mechanisms for compliance or if your organization is not subject to CAN-SPAM.',
        'help_text' => '',
      ),
      'dedupe_email_default' => array(
        'group_name' => 'Mailing Preferences',
        'group' => 'mailing',
        'name' => 'dedupe_email_default',
        'type' => 'Integer',
        'html_type' => 'checkbox',
        'default' => 1,
        'add' => '4.5',
        'title' => 'CiviMail dedupes e-mail addresses by default',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Set the \"dedupe e-mail\" option when sending a new mailing to \"true\" by default.',
        'help_text' => '',
      ),
      'hash_mailing_url' => array(
        'group_name' => 'Mailing Preferences',
        'group' => 'mailing',
        'name' => 'hash_mailing_url',
        'type' => 'Integer',
        'html_type' => 'checkbox',
        'default' => 0,
        'add' => '4.5',
        'title' => 'Hashed Mailing URL\'s',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'If enabled, a randomized hash key will be used to reference the mailing URL in the mailing.viewUrl token, instead of the mailing ID',
        'help_text' => '',
      ),
      'civimail_multiple_bulk_emails' => array(
        'group_name' => 'Mailing Preferences',
        'group' => 'mailing',
        'name' => 'civimail_multiple_bulk_emails',
        'type' => 'Integer',
        'html_type' => 'checkbox',
        'default' => 0,
        'add' => '4.5',
        'title' => ' Multiple Bulk Emails',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'If enabled, CiviMail will deliver a copy of the email to each bulk email listed for the contact.',
        'help_text' => '',
      ),
      'include_message_id' => array(
        'group_name' => 'Mailing Preferences',
        'group' => 'mailing',
        'name' => 'include_message_id',
        'type' => 'Integer',
        'html_type' => 'checkbox',
        'default' => '',
        'add' => '4.5',
        'title' => 'Enable CiviMail to generate Message-ID header',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'mailerBatchLimit' => array(
        'group_name' => 'Mailing Preferences',
        'group' => 'mailing',
        'name' => 'mailerBatchLimit',
        'type' => 'Integer',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'html_attributes' => array(
          'size' => 4,
          'maxlength' => 8,
        ),
        'default' => 0,
        'add' => '4.7',
        'title' => 'Mailer Batch Limit',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Throttle email delivery by setting the maximum number of emails sent during each CiviMail run (0 = unlimited).',
        'help_text' => '',
      ),
      'mailerJobSize' => array(
        'group_name' => 'Mailing Preferences',
        'group' => 'mailing',
        'name' => 'mailerJobSize',
        'type' => 'Integer',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'html_attributes' => array(
          'size' => 4,
          'maxlength' => 8,
        ),
        'default' => 0,
        'add' => '4.7',
        'title' => 'Mailer Job Size',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'If you want to utilize multi-threading enter the size you want your sub jobs to be split into. Recommended values are between 1,000 and 10,000. Use a lower value if your server has multiple cron jobs running simultaneously, but do not use values smaller than 1,000. Enter \"0\" to disable multi-threading and process mail as one single job - batch limits still apply.',
        'help_text' => '',
      ),
      'mailerJobsMax' => array(
        'group_name' => 'Mailing Preferences',
        'group' => 'mailing',
        'name' => 'mailerJobsMax',
        'type' => 'Integer',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'html_attributes' => array(
          'size' => 4,
          'maxlength' => 8,
        ),
        'default' => 0,
        'add' => '4.7',
        'title' => 'Mailer Cron Job Limit',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'The maximum number of mailer delivery jobs executing simultaneously (0 = allow as many processes to execute as started by cron)',
        'help_text' => '',
      ),
      'mailThrottleTime' => array(
        'group_name' => 'Mailing Preferences',
        'group' => 'mailing',
        'name' => 'mailThrottleTime',
        'type' => 'Integer',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'html_attributes' => array(
          'size' => 4,
          'maxlength' => 8,
        ),
        'default' => 0,
        'add' => '4.7',
        'title' => 'Mailer Throttle Time',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'The time to sleep in between each e-mail in micro seconds. Setting this above 0 allows you to control the rate at which e-mail messages are sent to the mail server, avoiding filling up the mail queue very quickly. Set to 0 to disable.',
        'help_text' => '',
      ),
      'verpSeparator' => array(
        'group_name' => 'Mailing Preferences',
        'group' => 'mailing',
        'name' => 'verpSeparator',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'html_attributes' => array(
          'size' => 4,
          'maxlength' => 32,
        ),
        'default' => '.',
        'add' => '4.7',
        'title' => 'VERP Separator',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Separator character used when CiviMail generates VERP (variable envelope return path) Mail-From addresses.',
        'help_text' => '',
      ),
      'write_activity_record' => array(
        'group_name' => 'Mailing Preferences',
        'group' => 'mailing',
        'name' => 'write_activity_record',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => '1',
        'add' => '4.7',
        'title' => 'Enable CiviMail to create activities on delivery',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'geoAPIKey' => array(
        'add' => '4.7',
        'help_text' => '',
        'is_domain' => 1,
        'is_contact' => 0,
        'group_name' => 'Map Preferences',
        'group' => 'map',
        'name' => 'geoAPIKey',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'html_attributes' => array(
          'size' => '32',
          'maxlength' => '64',
        ),
        'default' => '',
        'title' => 'Geo Provider Key',
        'description' => 'Enter the API key or Application ID associated with your geocoding provider (not required for Yahoo).',
      ),
      'geoProvider' => array(
        'add' => '4.7',
        'help_text' => '',
        'is_domain' => 1,
        'is_contact' => 0,
        'group_name' => 'Map Preferences',
        'group' => 'map',
        'name' => 'geoProvider',
        'type' => 'String',
        'quick_form_type' => 'Select',
        'html_type' => 'Select',
        'html_attributes' => array(
          'class' => 'crm-select2',
        ),
        'pseudoconstant' => array(
          'callback' => 'CRM_Core_SelectValues::geoProvider',
        ),
        'default' => '',
        'title' => 'Geocoding Provider',
        'description' => 'You may choose a different webservice for geocoding. This is required if there is no geo-coding plugin for your selected mapping provider. You can leave the Geocoding fields blank if you are using Google as your mapping provider.',
      ),
      'mapAPIKey' => array(
        'add' => '4.7',
        'help_text' => '',
        'is_domain' => 1,
        'is_contact' => 0,
        'group_name' => 'Map Preferences',
        'group' => 'map',
        'name' => 'mapAPIKey',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'html_attributes' => array(
          'size' => '32',
          'maxlength' => '64',
        ),
        'default' => '',
        'title' => 'Map Provider Key',
        'description' => 'Enter your API Key or Application ID. An API Key is currently optional for Google Maps API, but may be helpful diagnosing any problems and required for higher volumes of requests. Refer to developers.google.com for the latest information.',
      ),
      'mapProvider' => array(
        'add' => '4.7',
        'help_text' => '',
        'is_domain' => 1,
        'is_contact' => 0,
        'group_name' => 'Map Preferences',
        'group' => 'map',
        'name' => 'mapProvider',
        'type' => 'String',
        'quick_form_type' => 'Select',
        'html_type' => 'Select',
        'html_attributes' => array(
          'class' => 'crm-select2',
        ),
        'pseudoconstant' => array(
          'callback' => 'CRM_Core_SelectValues::mapProvider',
        ),
        'default' => '',
        'title' => 'Mapping Provider',
        'description' => 'Choose the mapping provider that has the best coverage for the majority of your contact addresses.',
      ),
      'default_renewal_contribution_page' => array(
        'group_name' => 'Member Preferences',
        'group' => 'member',
        'name' => 'default_renewal_contribution_page',
        'type' => 'Integer',
        'html_type' => 'Select',
        'default' => '',
        'pseudoconstant' => array(
          'name' => 'contributionPage',
        ),
        'add' => '4.1',
        'title' => 'Default online membership renewal page',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'If you select a default online contribution page for self-service membership renewals, a \"renew\" link pointing to that page will be displayed on the Contact Dashboard for memberships which were entered offline. You will need to ensure that the membership block for the selected online contribution page includes any currently available memberships.',
        'help_text' => '',
      ),
      'is_enabled' => array(
        'group_name' => 'Multi Site Preferences',
        'group' => 'multisite',
        'name' => 'is_enabled',
        'title' => 'Multisite Is enabled',
        'type' => 'Integer',
        'default' => 0,
        'add' => '4.1',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Multisite is enabled',
        'help_text' => '',
      ),
      'domain_group_id' => array(
        'group_name' => 'Multi Site Preferences',
        'group' => 'multisite',
        'name' => 'domain_group_id',
        'title' => 'Multisite Domain Group',
        'type' => 'Integer',
        'default' => 0,
        'add' => '4.1',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'event_price_set_domain_id' => array(
        'group_name' => 'Multi Site Preferences',
        'group' => 'multisite',
        'name' => 'event_price_set_domain_id',
        'title' => 'Domain Event Price Set',
        'type' => 'Integer',
        'default' => 0,
        'add' => '4.1',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'uniq_email_per_site' => array(
        'group_name' => 'Multi Site Preferences',
        'group' => 'multisite',
        'name' => 'uniq_email_per_site',
        'type' => 'Integer',
        'title' => 'Unique Email per Domain?',
        'default' => 0,
        'add' => '4.1',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'search_autocomplete_count' => array(
        'group_name' => 'Search Preferences',
        'group' => 'Search Preferences',
        'name' => 'search_autocomplete_count',
        'type' => 'Integer',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'html_attributes' => array(
          'size' => 2,
          'maxlength' => 2,
        ),
        'default' => 10,
        'add' => '4.3',
        'title' => 'Autocomplete Results',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'The maximum number of contacts to show at a time when typing in an autocomplete field.',
        'help_text' => '',
      ),
      'enable_innodb_fts' => array(
        'group_name' => 'Search Preferences',
        'group' => 'Search Preferences',
        'name' => 'enable_innodb_fts',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => 0,
        'add' => '4.4',
        'title' => 'InnoDB Full Text Search',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Enable InnoDB full-text search optimizations. (Requires MySQL 5.6+)',
        'help_text' => '',
        'on_change' => array(
          '0' => array(
            '0' => 'CRM_Core_InnoDBIndexer',
            '1' => 'onToggleFts',
          ),
        ),
      ),
      'fts_query_mode' => array(
        'group_name' => 'Search Preferences',
        'group' => 'Search Preferences',
        'name' => 'fts_query_mode',
        'type' => 'String',
        'quick_form_type' => 'Element',
        'html_attributes' => array(
          'size' => 64,
          'maxlength' => 64,
        ),
        'html_type' => 'Text',
        'default' => 'simple',
        'add' => '4.5',
        'title' => 'How to handle full-tet queries',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => '',
        'help_text' => '',
      ),
      'includeOrderByClause' => array(
        'group_name' => 'Search Preferences',
        'group' => 'Search Preferences',
        'name' => 'includeOrderByClause',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => 1,
        'add' => '4.6',
        'title' => 'Include Order By Clause',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'If disabled, the search results will not be ordered. This may improve response time on search results on large datasets',
        'help_text' => '',
      ),
      'includeWildCardInName' => array(
        'group_name' => 'Search Preferences',
        'group' => 'Search Preferences',
        'name' => 'includeWildCardInName',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => 1,
        'add' => '4.6',
        'title' => 'Automatic Wildcard',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'If enabled, wildcards are automatically added to the beginning AND end of the search term when users search for contacts by Name. EXAMPLE: Searching for \'ada\' will return any contact whose name includes those letters - e.g. \'Adams, Janet\', \'Nadal, Jorge\', etc. If disabled, a wildcard is added to the end of the search term only. EXAMPLE: Searching for \'ada\' will return any contact whose last name begins with those letters - e.g. \'Adams, Janet\' but NOT \'Nadal, Jorge\'. Disabling this feature will speed up search significantly for larger databases, but users must manually enter wildcards (\'%\' or \'_\') to the beginning of the search term if they want to find all records which contain those letters. EXAMPLE: \'%ada\' will return \'Nadal, Jorge\'.',
        'help_text' => '',
      ),
      'includeEmailInName' => array(
        'group_name' => 'Search Preferences',
        'group' => 'Search Preferences',
        'name' => 'includeEmailInName',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => 1,
        'add' => '4.6',
        'title' => 'Include Email',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'If enabled, email addresses are automatically included when users search by Name. Disabling this feature will speed up search significantly for larger databases, but users will need to use the Email search fields (from Advanced Search, Search Builder, or Profiles) to find contacts by email address.',
        'help_text' => '',
      ),
      'includeNickNameInName' => array(
        'group_name' => 'Search Preferences',
        'group' => 'Search Preferences',
        'name' => 'includeNickNameInName',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => 0,
        'add' => '4.6',
        'title' => 'Include Nickname',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'If enabled, nicknames are automatically included when users search by Name.',
        'help_text' => '',
      ),
      'includeAlphabeticalPager' => array(
        'group_name' => 'Search Preferences',
        'group' => 'Search Preferences',
        'name' => 'includeAlphabeticalPager',
        'type' => 'Boolean',
        'quick_form_type' => 'YesNo',
        'default' => 1,
        'add' => '4.6',
        'title' => 'Include Alphabetical Pager',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'If disabled, the alphabetical pager will not be displayed on the search screens. This will improve response time on search results on large datasets.',
        'help_text' => '',
      ),
      'smartGroupCacheTimeout' => array(
        'group_name' => 'Search Preferences',
        'group' => 'Search Preferences',
        'name' => 'smartGroupCacheTimeout',
        'type' => 'Integer',
        'quick_form_type' => 'Element',
        'html_type' => 'text',
        'default' => 5,
        'add' => '4.6',
        'title' => 'Smart group cache timeout',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'The number of minutes to cache smart group contacts. We strongly recommend that this value be greater than zero, since a value of zero means no caching at all. If your contact data changes frequently, you should set this value to at least 5 minutes.',
        'help_text' => '',
      ),
      'defaultSearchProfileID' => array(
        'group_name' => 'Search Preferences',
        'group' => 'Search Preferences',
        'name' => 'defaultSearchProfileID',
        'type' => 'Integer',
        'quick_form_type' => 'Select',
        'html_type' => 'Select',
        'html_attributes' => array(
          'class' => 'crm-select2',
        ),
        'pseudoconstant' => array(
          'callback' => 'CRM_Admin_Form_Setting_Search::getAvailableProfiles',
        ),
        'default' => '',
        'add' => '4.6',
        'title' => 'Default Contact Search Profile',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'If set, this will be the default profile used for contact search.',
        'help_text' => '',
      ),
      'userFrameworkResourceURL' => array(
        'bootstrap_comment' => 'This is a boot setting which may be loaded during bootstrap. Defaults are loaded via SettingsBag::getSystemDefaults().',
        'group' => 'url',
        'group_name' => 'URL Preferences',
        'name' => 'userFrameworkResourceURL',
        'title' => 'CiviCRM Resource URL',
        'type' => 'String',
        'html_type' => 'Text',
        'quick_form_type' => 'Element',
        'default' => '',
        'add' => '4.1',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Absolute URL of the location where the civicrm module or component has been installed.',
        'help_text' => '',
        'validate_callback' => 'CRM_Utils_Rule::urlish',
      ),
      'imageUploadURL' => array(
        'bootstrap_comment' => 'This is a boot setting which may be loaded during bootstrap. Defaults are loaded via SettingsBag::getSystemDefaults().',
        'group' => 'url',
        'group_name' => 'URL Preferences',
        'title' => 'Image Upload URL',
        'name' => 'imageUploadURL',
        'type' => 'String',
        'html_type' => 'Text',
        'quick_form_type' => 'Element',
        'default' => '',
        'add' => '4.1',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'URL of the location for uploaded image files.',
        'help_text' => '',
        'validate_callback' => 'CRM_Utils_Rule::urlish',
      ),
      'customCSSURL' => array(
        'bootstrap_comment' => 'This is a boot setting which may be loaded during bootstrap. Defaults are loaded via SettingsBag::getSystemDefaults().',
        'group' => 'url',
        'group_name' => 'URL Preferences',
        'name' => 'customCSSURL',
        'title' => 'Custom CSS URL',
        'type' => 'String',
        'html_type' => 'Text',
        'quick_form_type' => 'Element',
        'default' => '',
        'add' => '4.1',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'You can modify the look and feel of CiviCRM by adding your own stylesheet. For small to medium sized modifications, use your css file to override some of the styles in civicrm.css. Or if you need to make drastic changes, you can choose to disable civicrm.css completely.',
        'help_text' => '',
        'validate_callback' => 'CRM_Utils_Rule::urlish',
      ),
      'extensionsURL' => array(
        'bootstrap_comment' => 'This is a boot setting which may be loaded during bootstrap. Defaults are loaded via SettingsBag::getSystemDefaults().',
        'group' => 'url',
        'group_name' => 'URL Preferences',
        'title' => 'Extension Resource URL',
        'name' => 'extensionsURL',
        'type' => 'String',
        'html_type' => 'Text',
        'quick_form_type' => 'Element',
        'default' => '',
        'add' => '4.1',
        'is_domain' => 1,
        'is_contact' => 0,
        'description' => 'Base URL for extension resources (images, stylesheets, etc). This should match extensionsDir.',
        'help_text' => '',
        'validate_callback' => 'CRM_Utils_Rule::urlish',
      ),
    ),
  );

  return $expectedResult;
}

/*
* This example has been generated from the API test suite.
* The test that created it is called "testGetFields"
* and can be found at:
* https://github.com/civicrm/civicrm-core/blob/master/tests/phpunit/api/v3/SettingTest.php
*
* You can see the outcome of the API tests at
* https://test.civicrm.org/job/CiviCRM-master-git/
*
* To Learn about the API read
* http://wiki.civicrm.org/confluence/display/CRMDOC/Using+the+API
*
* Browse the api on your own site with the api explorer
* http://MYSITE.ORG/path/to/civicrm/api
*
* Read more about testing here
* http://wiki.civicrm.org/confluence/display/CRM/Testing
*
* API Standards documentation:
* http://wiki.civicrm.org/confluence/display/CRM/API+Architecture+Standards
*/
